/* ============================================================================
 * File Name: DDS_2.h
 * Version 0.0
 *
 * Description:
 *   DDS24: 24-bit DDS frequency generator component (v 0.0)
 *   Produces two syncronous fractional frequency outputs (out1 and out2)
 *   Outputs out1 and out2 separated by variable 8-bit phase shift [0..255]. 
 *
 * Credits:
 *   based on original IQ_DDS code by <PSoC73>:
 *   http://www.cypress.com/?app=forum&id=2492&rID=88149
 * 
 *   Special thanks to <pavloven>, <vdvorak>, <kabron>
 *
 * Note:
 *   frequency resolution = clock_frequency / 2^24
 *   frequency maximum    = clock_frequency / 2
 *   frequency minimum    = clock_frequency / 2^24
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#ifndef DDS_2_H
#define DDS_2_H

#include <project.h>




#define true  1 // but not True
#define false 0 // but not False
    
    
/***************************************
*   Conditional Compilation Parameters
***************************************/

#define DDS_2_CLOCK_FREQ (double) 600   // input clock frequency
#define DDS_2_HARDWARE_LOAD       false   // load frequency and phase on hardware digital signal 
#define DDS_2_OUT2_ENABLED        false   // show out2 terminal
#define DDS_2_CR_ENABLE           false  // enable mode = SW or SW_&_HW
#define DDS_2_CONTROL_FREQ_API    true   // use API to set DDS frequency
#define DDS_2_CONTROL_PHASE_API   true   // use API to set out2 phase
 
    
/***************************************
*           API Constants
***************************************/   

#define DDS_2_PresetFreq          50  // preset startup frequency
#define DDS_2_PresetPhase         0  // preset startup phase


    
/***************************************
*        Function Prototypes
***************************************/

void   DDS_2_Init();                      // initialize DDS
void   DDS_2_Start();                     // Init and Enable DDS
void   DDS_2_Stop();                      // Stop (disable) DDS 
void   DDS_2_Enable();                    // Enable DDS (must init first) // todo: add _Enabled and _Initialized property
uint8  DDS_2_SetFrequency( double Freq ); // Set desired output frequency
void   DDS_2_SetPhase( uint8 Phase );     // set out2 phase
double DDS_2_GetOutFreq();                // read actual output frequency
double DDS_2_GetFrequency();              // return current set frequency 
uint8  DDS_2_GetPhase();                  // read phase 


#endif


/* [] END OF FILE */
