/* ============================================================================
 * Project Name: DDS24_sw
 *
 * Description:
 *   Demo project demonstrating use of DDS24 component for generation of
 *   tunable frequency and phase using API calls for updating DDS parameters
 *   (software timing) 
 *
 *   DDS24: 24-bit DDS frequency generator component (v 0.0)
 *   Produces two syncronous fractional frequency outputs (out1 and out2)
 *   Outputs out1 and out2 separated by variable 8-bit phase shift [0..255]. 
 *
 * Credits:
 *   based on original IQ_DDS code by <PSoC73>:
 *   http://www.cypress.com/?app=forum&id=2492&rID=88149
 * 
 *   Special thanks to <pavloven>, <vdvorak>, <kabron>
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>


//===========================================
// Global variables
//===========================================


//used to define max iteration
//Load new freq after this much iteration
#define MAX_iteration       100000

//used to define max ADC Count
#define MAX_ADC             1023

//used for Counter count freq
#define CounterEventClock   1000000

//used for MAX Frea
#define MAX_Freq            50


int main()
{
    //used to count itteration
    unsigned int uiIteration=0;
    
    //contains the ADC value
    unsigned int uiADC=0;
    
    //contains the Freq Value
    double dFreq;
    
    CyGlobalIntEnable;              //enable global interrupts.

    DDS_Start();                    // initialise and enable

    
    // instead of running infinite loop with delay I would recommend using a timer and interrupt
    // see demo DDS24_sw.proj provided with DDS componet
    
    for(;;) //forever
    {
        //increment itteration
        uiIteration++;
        
        //check if it is a time to change the freq
        if(uiIteration>=MAX_iteration)
        {
            //reset itteration count
            uiIteration=0;
            
            //increment ADC
            //uiADC=MAX_ADC;
            uiADC++;
            
            //check if it is at max
            if(uiADC>MAX_ADC)
            {
                //reset ADC    
                uiADC=0;
            }
            
            //check if ADC is zero
            if(uiADC==0)
            {
                //disable DDS
                DDS_Stop(); //DDS does not need to be stopped for update 
            }
            
            //else calculate period and compare
            else
            {
                //calculate Freq
                dFreq = (MAX_Freq * (double)uiADC) / MAX_ADC;
                
                // update frequency 
                DDS_SetFrequency(dFreq);   //Upload next frequency value into DDS buffer
                
                //enable DSS if disabled
                DDS_Enable();
                
                // there must be some delay between DDS updates
                // particularly because of very low frequency
                CyDelay(100);
            }
        }
    }  
    
} // main()
